// The contents of this file are subject to the Mozilla Public License
// Version 1.1 (the "License"); you may not use this file except in
// compliance with the License. You may obtain a copy of the License at
// http://www.mozilla.org/MPL/.  Software distributed under the License is
// distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either
// express or implied.  See the License for the specific language governing
// rights and limitations under the License.
//
// The Original Code is the FormSaver extension for Firefox.
// The Initial Developer is Ka-Ping Yee <ping@zesty.ca>.  Portions created
// by Ka-Ping Yee are Copyright (C) 2006 Ka-Ping Yee.  All rights reserved.

// This is a namespace-object style of Javascript.  Everything is defined
// in an object's namespace; internal functionality is provided in private
// member functions or private member objects.  Public functionality is
// explicitly exposed by assigning to attributes of 'this'.  The idiom
// "foo = new function() {...}" makes a new object, not a new function.

// This object contains all the functionality for the preferences dialog.
var formsaver = new function() {
    // Handy shorthand for getting at XPConnect services: XPI gets an
    // interface; XPC gets a class; XPS gets a service; XPO gets an object.
    var XPI = Components.interfaces;
    function XPC(c) { return Components.classes['@mozilla.org/' + c]; }
    function XPS(c, i) { return XPC(c) ? XPC(c).getService(i) : null; }
    function XPO(c, i) { return XPC(c) ? XPC(c).createInstance(i) : null; }

    // Get an element.
    function $(id) { return document.getElementById(id); }

    // This object provides access to the preferences.
    var prefs = new function() {
        var service = XPS('preferences-service;1', XPI.nsIPrefService);
        var branch = service.getBranch('formsaver.');
        this.getbool = function(name, value) {
            try { return branch.getBoolPref(name); }
            catch (error) { return value; }
        }
        this.setbool = function(name, value) {
            branch.setBoolPref(name, value);
        }
        this.register = function(observer) {
            var internal = branch.QueryInterface(XPI.nsIPrefBranchInternal);
            internal.addObserver('', observer, false);
        }
    }

    // Public methods.
    this.loadprefs = function() {
        $('requiremeta').checked = prefs.getbool('requiremeta', false);
    }

    this.saveprefs = function() {
        prefs.setbool('requiremeta', $('requiremeta').checked);
    }
};
